"use client";
import React, { useRef } from "react";
import { useAppContext } from "@/context/AppContext";
// Import Swiper React components
import { Swiper, SwiperSlide } from "swiper/react";
// Import Swiper styles
import "swiper/css";
import "swiper/css/pagination";
import "swiper/css/navigation";
// import required modules
import { Pagination } from "swiper/modules";
import star from "@/assets/star-6.svg";
import location from "@/assets/vector2.svg";
import fishing from "@/assets/images/rectangle-63@2x.png";
import bowrinderBoat from "@/assets/images/rectangle-58@2x.png";
import catamaran from "@/assets/images/rectangle-64@2x.png";
import house from "@/assets/images/Mask group.png";
import avatar1 from "@/assets/avators/Avatars 1.png";
import avatar2 from "@/assets/avators/Avatars 2.png";
import avatar3 from "@/assets/avators/Avatars 3.png";
import arrow_right from "@/assets/vector1.svg";
import Image from "next/image";
import Link from "next/link";
const avatars = [avatar1, avatar2, avatar3];
const photos = [fishing, bowrinderBoat, catamaran];
const boat_types = ["Fishing", "Bowrinder", "Catamaran"];
export default function BoatsSaleSlider() {
  const { boatsForSale } = useAppContext();
  const swiperRef = useRef(null);
  const slides = new Array(6).fill(null);
  const handlePrevSlide = () => {
    if (swiperRef.current && swiperRef.current.swiper) {
      swiperRef.current.swiper.slidePrev();
    }
  };

  const handleNextSlide = () => {
    if (swiperRef.current && swiperRef.current.swiper) {
      swiperRef.current.swiper.slideNext();
    }
  };

  const truncateTitle = (title) => {
    const words = title.split(" ");
    if (words.length > 3) {
      return words.slice(0, 3).join(" ") + "...";
    }
    return title;
  };

  return (
    <div className="container mx-auto">
      <div className="flex flex-row gap-3 items-center relative">
        <div
          onClick={handlePrevSlide}
          className="cursor-pointer absolute top-[50%] -left-12 z-40"
        >
          <div className="btn-gradient px-2 py-1 rounded">
            <Image
              src={arrow_right}
              alt="previous"
              className="transform rotate-180"
            />
          </div>
        </div>
        <Swiper
          slidesPerView={3}
          spaceBetween={20}
          hashNavigation={{
            watchState: true,
          }}
          loop={true}
          // pagination={{
          //   clickable: true,
          // }}
          modules={[Pagination]}
          ref={swiperRef}
        >
          {boatsForSale?.map((boatForSale, index) => (
            <SwiperSlide key={index}>
              <div className="mx-2 mb-2 shadow-[0px_0px_8px_rgba(0,_0,_0,_0.15)] rounded-md bg-white">
                <figure className="">
                  <Image
                    width={414}
                    height={275}
                    className="rounded-md object-cover !h-[275px] "
                    alt=""
                    src={boatForSale.thumbnailImg?.images[0]?.url}
                  />
                </figure>
                <div className="flex flex-col">
                  <div className="flex flex-col px-4 py-2 space-y-3">
                    <div className="flex flex-row items-center">
                      {Array.from({ length: 5 }, (_, index) => (
                        <div key={index} className="h-5 w-5">
                          <Image width={20} height={20} src={star.src} />
                        </div>
                      ))}
                      <div className="ms-3 opacity-[50%]">5.0</div>
                      <div className="opacity-[50%] ms-3">(20 Reviews)</div>
                    </div>
                    <Link
                      href={`/boat/${boatForSale.slug}`}
                      className="flex text-[#002D4F] text-xl font-medium w-full text-left"
                    >
                      {truncateTitle(boatForSale.title)}
                    </Link>
                    <div className="text-[#002D4F] flex flex-row space-x-2 w-full text-base items-start">
                      <div className="inline-block w-3.5">
                        <Image
                          width={20}
                          height={20}
                          alt=""
                          src={location.src}
                        />
                      </div>
                      <div className="flex truncate overflow-ellipsis">
                        {boatForSale.neighbourhood}
                      </div>
                    </div>
                  </div>
                  <div className="box-border my-3 w-full h-0.5 border-t-[2px] border-solid border-[#969696]" />
                  <div className="flex flex-row items-center justify-between pb-4 px-5">
                    <div className="flex flex-row gap-4 items-center">
                      <div className="flex w-[50px] h-[50px]">
                        <Image
                          width={50}
                          height={50}
                          className="object-cover"
                          alt=""
                          src={avatars[index % avatars.length]}
                        />
                      </div>
                      <div className="text-base font-medium text-[#000000]">
                        Ref: 12390876
                      </div>
                    </div>
                    <div className="text-lg font-semibold text-[#000000]">
                      ${boatForSale.price}
                    </div>
                  </div>
                </div>
              </div>
            </SwiperSlide>
          ))}
        </Swiper>
        <div
          onClick={handleNextSlide}
          className="cursor-pointer absolute top-[50%] -right-12 z-40"
        >
          <div className="btn-gradient px-2 py-1 rounded">
            <Image src={arrow_right} alt="next" />
          </div>
        </div>
      </div>
    </div>
  );
}
